Index: webrtc/logging/rtc_event_log/rtc_event_log_parser.h |
diff --git a/webrtc/logging/rtc_event_log/rtc_event_log_parser.h b/webrtc/logging/rtc_event_log/rtc_event_log_parser.h |
index 8472668d75229762ad6671883f1428fdfe910e8c..739ccee220693cc42e070cf91df87e74fac6d60f 100644 |
--- a/webrtc/logging/rtc_event_log/rtc_event_log_parser.h |
+++ b/webrtc/logging/rtc_event_log/rtc_event_log_parser.h |
@@ -42,8 +42,8 @@ class ParsedRtcEventLog { |
RTP_EVENT = 3, |
RTCP_EVENT = 4, |
AUDIO_PLAYOUT_EVENT = 5, |
- BWE_PACKET_LOSS_EVENT = 6, |
- BWE_PACKET_DELAY_EVENT = 7, |
+ LOSS_BASED_BWE_UPDATE = 6, |
+ DELAY_BASED_BWE_UPDATE = 7, |
VIDEO_RECEIVER_CONFIG_EVENT = 8, |
VIDEO_SENDER_CONFIG_EVENT = 9, |
AUDIO_RECEIVER_CONFIG_EVENT = 10, |
@@ -71,8 +71,8 @@ class ParsedRtcEventLog { |
// Reads the header, direction, media type, header length and packet length |
// from the RTP event at |index|, and stores the values in the corresponding |
- // output parameters. The output parameters can be set to nullptr if those |
- // values aren't needed. |
+ // output parameters. Each output parameter can be set to nullptr if that |
+ // value isn't needed. |
// NB: The header must have space for at least IP_PACKET_SIZE bytes. |
void GetRtpHeader(size_t index, |
PacketDirection* incoming, |
@@ -83,7 +83,7 @@ class ParsedRtcEventLog { |
// Reads packet, direction, media type and packet length from the RTCP event |
// at |index|, and stores the values in the corresponding output parameters. |
- // The output parameters can be set to nullptr if those values aren't needed. |
+ // Each output parameter can be set to nullptr if that value isn't needed. |
// NB: The packet must have space for at least IP_PACKET_SIZE bytes. |
void GetRtcpPacket(size_t index, |
PacketDirection* incoming, |
@@ -115,15 +115,24 @@ class ParsedRtcEventLog { |
void GetAudioPlayout(size_t index, uint32_t* ssrc) const; |
// Reads bitrate, fraction loss (as defined in RFC 1889) and total number of |
- // expected packets from the BWE event at |index| and stores the values in |
- // the corresponding output parameters. The output parameters can be set to |
- // nullptr if those values aren't needed. |
- // NB: The packet must have space for at least IP_PACKET_SIZE bytes. |
- void GetBwePacketLossEvent(size_t index, |
- int32_t* bitrate, |
+ // expected packets from the loss based BWE event at |index| and stores the |
+ // values in |
+ // the corresponding output parameters. Each output parameter can be set to |
+ // nullptr if that |
+ // value isn't needed. |
+ void GetLossBasedBweUpdate(size_t index, |
+ int32_t* bitrate_bps, |
uint8_t* fraction_loss, |
int32_t* total_packets) const; |
+ // Reads bitrate and detector_state from the delay based BWE event at |index| |
+ // and stores the values in the corresponding output parameters. Each output |
+ // parameter can be set to nullptr if that |
+ // value isn't needed. |
+ void GetDelayBasedBweUpdate(size_t index, |
+ int32_t* bitrate_bps, |
+ BandwidthUsage* detector_state) const; |
+ |
// Reads a audio network adaptation event to a (non-NULL) |
// AudioNetworkAdaptor::EncoderRuntimeConfig struct. Only the fields that are |
// stored in the protobuf will be written. |